/*
** Module   : SensitiveResource.java
** Abstract : Abstract class which will hold the  most common methods of the
**            CommonHandleChain interface plus the Sensitive interface 
**            implementation.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 CS  20130207 Created initial version.
** 002 CA  20130908 Fixed field assignment.
*/

package com.goldencode.p2j.util;

/** 
 * Abstract class which adds {@link Sensitive} flavor on the of {@link HandleChain}. 
 */
public abstract class SensitiveResource 
extends HandleChain 
implements Sensitive 
{
   /** Variable for the SENSITIVE attribute */
   private logical sensitive = new logical(true);

   /**
    * Java implementation for getting the  SENSITIVE handle attribute which
    * contains a <code>logical</code> value that determines if the handle 
    * can receive input focus or events.
    * <p>
    * If <code>false</code> the response procedure will not be executed.
    * 
    * @return The logical value of the socket which determines if the handle 
    *         can receive input focus or events.
    */
   public logical isSensitive()
   {
      return new logical(sensitive);
   }
  
   /**
    * Java implementation for setting the  SENSITIVE handle attribute which
    * contains a <code>logical</code> value that determines if the handle 
    * can receive input focus or events.
    * <p>
    * If set to <code>false</code> the response procedure will not be executed.
    * 
    * @param sensitive
    *        The logical value which the socket which determines if the handle 
    *        can receive input focus or events to be set.
    */
   public void setSensitive(String sensitive)
   {
      setSensitive(new logical(sensitive));
   }
  
   /**
    * Java implementation for setting the  SENSITIVE handle attribute which
    * contains a <code>logical</code> value that determines if the handle 
    * can receive input focus or events.
    * <p>
    * If set to <code>false</code> the response procedure will not be executed.
    * 
    * @param sensitive
    *        The logical value which the socket which determines if the handle 
    *        can receive input focus or events, to be set.
    */
   public void setSensitive(character sensitive)
   {
      setSensitive(new logical(sensitive));
   }
   
   /**
    * Java implementation for setting the  SENSITIVE handle attribute which
    * contains a <code>logical</code> value that determines if the handle 
    * can receive input focus or events.
    * <p>
    * If set to <code>false</code> the response procedure will not be executed.
    * 
    * @param sensitive
    *        The logical value which the socket which determines if the handle 
    *        can receive input focus or events, to be set.
    */
   public void setSensitive(boolean sensitive)
   {
      setSensitive(new logical(sensitive));
   }
  
   /**
    * Java implementation for setting the  SENSITIVE handle attribute which
    * contains a <code>logical</code> value that determines if the handle 
    * can receive input focus or events.
    * <p>
    * If set to <code>false</code> the response procedure will not be executed.
    * 
    * @param sensitive
    *        The logical value which the socket which determines if the handle 
    *        can receive input focus or events, to be set.
    */
   public void setSensitive(logical sensitive)
   {
      this.sensitive.assign(sensitive);
   }
}
