/*
** Module   : SocketFactory.java
** Abstract : A class for instantiating SOCKET handles.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --------------------------------Description-----------------------------------
** 001 CS  20130204 Created initial version.
** 002 CA  20130916 Do not allow server sockets on appserver calls.
*/

package com.goldencode.p2j.util;

/**
 * A class for instantiating socket handles.
 */
public class SocketFactory
{
   /**
    * Method for assigning a <code>SocketImpl</code> to the handle defining it 
    * as a socket.
    * 
    * @param socketHandle
    *        The handle to which we will assign the socket
    */
   public static void createSocket(handle socketHandle)
   {
      socketHandle.assign(getSocket());
   }
   
   /**
    * Method for assigning a <code>SocketListenerImpl</code> to the handle 
    * defining it as a server-socket.
    * 
    * @param socketHandle
    *        The handle to which we will assign the socket
    */
   public static void createServerSocket(handle socketHandle)
   {
      if (AppServerManager.isRemote())
      {
         final String msg1 = "CREATE SERVER-SOCKET can not be called from an Appserver";
         final String msg2 = "Cannot create widget of type SERVER-SOCKET";
         
         ErrorManager.recordOrThrowError(new int[]    { 9353, 3181 },
                                         new String[] { msg1, msg2},
                                         false);
         
         return;
      }
      
      socketHandle.assign(getServerSocket());
   }
   
   /**
    * Method which returns a new SocketListenerImpl.
    * 
    * @return a new SocketListenerImpl as a WrappedResource.
    */
   private static WrappedResource getServerSocket()
   {
      return new SocketListenerImpl();
   }
   
   /**
    * Method which returns a new SocketImpl.
    * 
    * @return a new SocketImpl as a WrappedResource.
    */
   private static WrappedResource getSocket()
   {
      return new SocketImpl();
   }
}
